<template>
  <div id="accounting">
    <div style="display: flex; justify-content: space-between; align-items: baseline;">
      <h1>Sales</h1>
      <p
        v-if="Object.keys(salesObject).length"
        style="font-size: 2.2em; !important"
        class="salesIncomeTotal">Total: ${{ salesObject.totalSales.toFixed(2) }}
      </p>
      <p
        v-else
        style="font-size: 2.2em; !important">Total: $0.00
      </p>
      <a
        class="expand button"
        style="width: 155px; text-align: center;"
        @click="expandSales = !expandSales">
        <p
          v-if="expandSales"
          style="margin: 0;">Hide Sales
        </p>
        <p
          v-else
          style="margin: 0;">Show Sales
        </p>
      </a>
    </div>
    <table
      id="salesIncomeTable"
      :class="{'closed':!expandSales}"
      class="sales">
      <thead v-if="expandSales === true">
        <tr>
          <th>Time</th>
          <th>To</th>
          <th>Account Number</th>
          <th>Amount</th>
          <th>Options</th>
        </tr>
      </thead>
      <tbody v-if="Object.keys(salesObject).length && expandSales == true" >
        <tr
          v-for="(sale, index) in salesObject.sales"
          :key="index">
          <td>{{ moment.utc(sale.time).local().format('h:mm A') }}</td>
          <td>{{ sale.account_name }}</td>
          <td>{{ sale.from }}</td>
          <td>${{ sale.amount.toFixed(2) }}</td>
          <td><a
            class="voidTransaction button"
            @click="deleteSale(sale)" >VOID</a></td>
        </tr>
      </tbody>
      <!-- <tfoot>
        <tr
          style="background: rgba(255, 255, 255, 0.1); !important"
          class="lastrow">
          <td>Sales Total</td>
          <td
            v-if="salesObject.totalSales"
            style="font-size: 2.2em; !important"
            class="salesIncomeTotal">${{ salesObject.totalSales.toFixed(2) }}</td>
          <td
            v-else
            style="font-size: 2.2em; !important" >$0.00</td>
          <td>&nbsp;</td>
          <td><a
            class="expand"
            @click="expandSales = !expandSales"><span class="arrow-down"/><span class="arrow-right"/></a></td>
          <td>&nbsp;</td>
        </tr>
      </tfoot> -->
    </table>
    <div style="display: flex; justify-content: space-between; align-items: baseline;">
      <h1>Expenses</h1>
      <!-- <p
        v-if="paymentObject.outstanding"
        id="outstanding"
        style="font-size: 2.2em; !important">Total: ${{ paymentObject.outstanding.toFixed(2) }}
      </p>
      <p
        v-else
        style="font-size: 2.2em; !important">Total: $0.00
      </p>
      <div style="width: 80px;" /> -->
    </div>
    <section>
      <table
        id="businessExpenseTable"
        class="business">
        <ul
          class="errors"
          style="display: none;"/>
        <thead>
          <tr>
            <th>To Shop</th>
            <th>Amount Due</th>
            <th>Payment Status</th>
          </tr>
        </thead>
        <tbody v-if="paymentObject.payments">
          <tr
            v-for="(payment, index) in paymentObject.payments"
            :key="index">
            <td>{{ payment.to }}</td>
            <td>
              <span
                v-if="payment.fake_paid === false"
                class="amount">${{ (payment.amount).toFixed(2) }}
              </span>
              <span
                v-if="payment.fake_paid === true"
                class="amount">$0.00
              </span>
            </td>
            <td>
              <span
                v-if="payment.fake_paid === true"
                class="amount">Paid</span>
              <a
                v-if="payment.fake_paid === false"
                class="button paymentlink"
                @click="togglePayment(payment)">Pay</a>
            </td>
          </tr>
        </tbody>
        <!-- <tfoot>
          <tr>
            <td><span class="totaltxt">Amount Outstanding</span></td>
            <td/>
            <td><span class="totaltxt">Total paid</span></td>
          </tr>
          <tr class="lastrow">
            <td>Total</td>
            <td
              v-if="paymentObject.outstanding"
              id="outstanding">${{ paymentObject.outstanding.toFixed(2) }}</td>
            <td/>
            <td
              v-if="paymentObject.received"
              id="received">${{ paymentObject.received.toFixed(2) }}</td>
          </tr>
        </tfoot> -->
      </table>
    </section>
    <!-- <h1>Total</h1>
    <table class="total">
      <tfoot>
        <tr class="lastrow">
          <td>Business Income + Sales Income</td>
          <td>&nbsp;</td>
          <td>&nbsp;</td>
          <td>
            <span
              v-if="!Object.keys(salesObject).length && !Object.keys(paymentObject).length"
              class="totalIncome">$0.00
            </span>
            <span
              v-else-if="!Object.keys(salesObject).length && Object.keys(paymentObject).length"
              class="totalIncome">${{ (paymentObject.received).toFixed(2) }}
            </span>
            <span
              v-else-if="Object.keys(salesObject).length && !Object.keys(paymentObject).length"
              class="totalIncome">${{ (salesObject.totalSales).toFixed(2) }}
            </span>
            <span
              v-else
              class="totalIncome">${{ (paymentObject.received + salesObject.totalSales).toFixed(2) }}
            </span>
          </td>
        </tr>
      </tfoot>
    </table> -->
  </div>

</template>

<script>
export default {
  props: {
    shop: Object,
  },
  data(){
    return{
      paymentObject:Object,
      salesObject:Object,
      expandSales:false,
      intervalID: ""
    };
  },
  created: function() {
    this.getPaymentData();
    this.getSalesData();
    this.poller();
  },
  destroyed: function() {
    clearInterval(this.intervalID);
  },
  methods : {
    getPaymentData(){
      app.api.Get( "/shop_payment/getPaymentsByShopType/" + this.shop.canonical_name).then( response => {
        this.paymentObject = response;
      }
    );},
  togglePayment(payment){
    app.api.Put( "/shop_payment/toggleByShopPayment/" + payment.id).then( response => {
      this.getPaymentData();
    });
    },
  getSalesData(){
      app.api.Get( "/transaction/getSalesByShop/" + this.shop.canonical_name).then( response => {
        this.salesObject = response;
      });
    },
    deleteSale(sale){
        var result = confirm( "Void payment?" );
        if(result){
          app.api.Delete( "/transaction/" + sale.id).then( response => {
            this.getSalesData();
        });
      }
    },
    poller() {
      this.intervalID = setInterval(() => {
        this.getSalesData();
      }, 10000);
    }
  }
};
</script>

<style>

</style>
